@@ -1,10 +1,14 @@
 from django.conf.urls.defaults import *
 from django.conf import settings
+from django.contrib import admin
+
+admin.autodiscover()
 
 urlpatterns = patterns('',
-    #(r'^accounts/', include('registration.urls')),
     (r'', include('richtemplates.examples.urls')),
 
+    (r'^accounts/', include('registration.urls')),
+    (r'^admin/', include(admin.site.urls)),
 )
 
 if settings.DEBUG:
